/* Switch */
.switch-wrapper {
    position: relative;
    display: inline-flex;
    align-items: center;
    width: 44px;
    height: 24px;
    margin-right: 8px;
    margin-bottom: 0;
}
.switch-wrapper input[type="checkbox"] {
    opacity: 0;
    width: 0;
    height: 0;
}
.switch-slider {
    position: absolute;
    cursor: pointer;
    top: 0; left: 0; right: 0; bottom: 0;
    background: var(--switch-bg);
    border-radius: 24px;
    transition: background 0.2s;
}
.switch-wrapper input[type="checkbox"]:checked + .switch-slider {
    background: var(--switch-checked-bg);
}
.switch-slider:before {
    content: "";
    position: absolute;
    left: 4px;
    top: 4px;
    width: 16px;
    height: 16px;
    background: #fff;
    border-radius: 50%;
    transition: transform 0.2s;
}
.switch-wrapper input[type="checkbox"]:checked + .switch-slider:before {
    transform: translateX(20px);
}