/**
 * Range Sliders Component Styles
 * Styling for the dual-slider range component
 */

.range-sliders-container {
    width: 100%;
    padding: 20px;
    display: flex;
    flex-direction: column;
    align-items: center;
}

.sliders-wrapper {
    width: 100%;
    position: relative;
    padding: 10px 0;
}

.range-slider {
    width: 100%;
    margin: 10px 0;
    -webkit-appearance: none;
    background: transparent;
}

.range-slider::-webkit-slider-thumb {
    -webkit-appearance: none;
    height: 24px;
    width: 24px;
    border-radius: 50%;
    background: #ffffff;
    cursor: pointer;
    margin-top: -10px;
    box-shadow: 0 2px 6px rgba(0,0,0,0.2);
    border: 2px solid #D2691E;
    transition: all 0.2s ease;
}

.range-slider::-webkit-slider-thumb:hover {
    transform: scale(1.1);
    box-shadow: 0 4px 10px rgba(0,0,0,0.3);
}

.range-slider::-webkit-slider-runnable-track {
    width: 100%;
    height: 4px;
    background: rgba(255,255,255,0.3);
    border-radius: 2px;
}

.range-display {
    display: flex;
    justify-content: center;
    align-items: center;
    margin-top: 20px;
    font-size: 20px;
    color: #ffffff;
    font-weight: bold;
    text-shadow: 1px 1px 3px rgba(0,0,0,0.2);
}

.range-value {
    min-width: 60px;
    text-align: center;
    padding: 5px 10px;
    background: rgba(255,255,255,0.1);
    border-radius: 15px;
    margin: 0 10px;
}

/* Firefox support */
.range-slider::-moz-range-thumb {
    height: 24px;
    width: 24px;
    border-radius: 50%;
    background: #ffffff;
    cursor: pointer;
    box-shadow: 0 2px 6px rgba(0,0,0,0.2);
    border: 2px solid #D2691E;
    transition: all 0.2s ease;
}

.range-slider::-moz-range-thumb:hover {
    transform: scale(1.1);
    box-shadow: 0 4px 10px rgba(0,0,0,0.3);
}

.range-slider::-moz-range-track {
    width: 100%;
    height: 4px;
    background: rgba(255,255,255,0.3);
    border-radius: 2px;
}

/* Edge/IE support */
.range-slider::-ms-thumb {
    height: 24px;
    width: 24px;
    border-radius: 50%;
    background: #ffffff;
    cursor: pointer;
    box-shadow: 0 2px 6px rgba(0,0,0,0.2);
    border: 2px solid #D2691E;
    transition: all 0.2s ease;
}

.range-slider::-ms-thumb:hover {
    transform: scale(1.1);
    box-shadow: 0 4px 10px rgba(0,0,0,0.3);
}

.range-slider::-ms-track {
    width: 100%;
    height: 4px;
    background: rgba(255,255,255,0.3);
    border-radius: 2px;
    border-color: transparent;
    color: transparent;
}

.range-slider::-ms-fill-lower {
    background: rgba(255,255,255,0.3);
    border-radius: 2px;
}

.range-slider::-ms-fill-upper {
    background: rgba(255,255,255,0.3);
    border-radius: 2px;
}