/* Rate (stars) */
.rate-wrapper {
    display: flex;
    gap: 4px;
    font-size: 1.5rem;
    margin-bottom: 10px;
}
.rate-star {
    color: var(--rate-star-empty);
    cursor: pointer !important;
    transition: color 0.2s;
    user-select: none;
    position: relative;
    font-size: 2em;
}
.rate-star:hover {
    transform: scale(1.1);
}
.rate-star.filled {
    color: var(--rate-star);
}
.rate-star.half {
    color: var(--rate-star);
}
.rate-star.half:after {
    content: "★";
    color: var(--rate-star-empty);
    position: absolute;
    left: 50%;
    top: 0;
    width: 50%;
    overflow: hidden;
    z-index: 1;
}