/* Checkbox */
.checkbox-wrapper {
    display: flex;
    align-items: center;
    gap: 12px;
    margin-bottom: 12px;
    font-size: 1rem;
    cursor: pointer;
    padding: 8px 0 8px 4px;
    border-radius: 4px;
    transition: background 0.2s;
}
.checkbox-wrapper:hover {
    background: #f5f5f5;
}
.checkbox-wrapper input[type="checkbox"] {
    accent-color: var(--checkbox-accent);
    width: 18px;
    height: 18px;
    margin: 0 6px 0 0;
}
select option {
    padding: 8px 12px;
}