/* Radio */
.radio-group {
    display: flex;
    gap: 20px;
    margin-bottom: 14px;
    padding: 4px 0 4px 2px;
}
.radio-wrapper {
    display: flex;
    align-items: center;
    gap: 8px;
    font-size: 1rem;
    cursor: pointer;
    padding: 6px 0 6px 2px;
    border-radius: 4px;
    transition: background 0.2s;
}
.radio-wrapper:hover {
    background: #f5f5f5;
}
.radio-wrapper input[type="radio"] {
    accent-color: var(--primary-color);
    width: 18px;
    height: 18px;
    margin: 0 6px 0 0;
}