  /* Upload */
.upload-wrapper {
    display: flex;
    align-items: center;
    justify-content: center;
    border: 2px dashed var(--upload-border);
    border-radius: var(--input-radius);
    padding: 20px;
    background: #fafafa;
    color: var(--font-color);
    margin-bottom: 10px;
    min-height: 60px;
}
.upload-wrapper input[type="file"] {
    width: auto;
    margin: 0;
    border: none;
    background: transparent;
    box-shadow: none;
    padding: 0;
}
/* Search input wrapper */
.search-input-wrapper {
    display: flex;
    align-items: center;
    gap: 8px;
    margin-bottom: 10px;
}